// @flow
import React from 'react'
import ReactDOM from 'react-dom'
import { AppContainer } from 'react-hot-loader'
import { createStore, applyMiddleware } from 'redux'
import { Provider } from 'react-redux'
import createSagaMiddleware from 'redux-saga'
import { composeWithDevTools } from 'redux-devtools-extension'
import 'sanitize.css/sanitize.css'

import registerServiceWorker from './registerServiceWorker'
import Routes from './components/Routes'
import rootReducer from './reducers'
import rootSaga from './sagas'

const rootEl = document.getElementById('root')

const sagaMiddleware = createSagaMiddleware()

const middleware = [sagaMiddleware]

const middlewaresWithDevTools = composeWithDevTools(applyMiddleware(...middleware))

const store = createStore(rootReducer, middlewaresWithDevTools)

sagaMiddleware.run(rootSaga)

const render = Component => {
  ReactDOM.render(
    <AppContainer>
      <Provider store={store}>
        <Component />
      </Provider>
    </AppContainer>,
    rootEl
  )
}

render(Routes)

if (module.hot) {
  module.hot.accept('./components/commons', () => {
    render(Routes)
  })
}

registerServiceWorker()
